@@ -11,7 +11,7 @@ use base qw/DBIx::Class/;
 __PACKAGE__->load_components(qw/AccessorGroup/);
 
 __PACKAGE__->mk_group_accessors('simple' =>
-  qw/_ordered_columns _columns _primaries name resultset_class result_class schema from _relationships/);
+  qw/_ordered_columns _columns _primaries _unique_constraints name resultset_class result_class schema from _relationships/);
 
 =head1 NAME 
 
@@ -108,6 +108,21 @@ Returns the column metadata hashref for a column.
 sub column_info {
   my ($self, $column) = @_;
   croak "No such column $column" unless exists $self->_columns->{$column};
+  if ( (! $self->_columns->{$column}->{data_type})
+       && $self->schema && $self->storage() ){
+      my $info;
+############ eval for the case of storage without table 
+      eval{
+          $info = $self->storage->columns_info_for ( $self->from() );
+      };
+      if ( ! $@ ){
+          for my $col ( keys %{$self->_columns} ){
+              for my $i ( keys %{$info->{$col}} ){
+                  $self->_columns()->{$col}->{$i} = $info->{$col}->{$i};
+              }
+          }
+      }
+  }
   return $self->_columns->{$column};
 }
 
@@ -116,20 +131,22 @@ sub column_info {
   my @column_names = $obj->columns;
 
 Returns all column names in the order they were declared to add_columns
-                                                                                
-=cut                                                                            
+
+=cut
 
 sub columns {
   croak "columns() is a read-only accessor, did you mean add_columns()?" if (@_ > 1);
   return @{shift->{_ordered_columns}||[]};
 }
 
-=head2 set_primary_key(@cols)                                                   
-                                                                                
+=head2 set_primary_key(@cols)
+
 Defines one or more columns as primary key for this source. Should be
 called after C<add_columns>.
-                                                                                
-=cut                                                                            
+
+Additionally, defines a unique constraint named C<primary>.
+
+=cut
 
 sub set_primary_key {
   my ($self, @cols) = @_;
@@ -139,18 +156,53 @@ sub set_primary_key {
       unless $self->has_column($_);
   }
   $self->_primaries(\@cols);
+
+  $self->add_unique_constraint(primary => \@cols);
 }
 
-=head2 primary_columns                                                          
-                                                                                
+=head2 primary_columns
+
 Read-only accessor which returns the list of primary keys.
 
-=cut                                                                            
+=cut
 
 sub primary_columns {
   return @{shift->_primaries||[]};
 }
 
+=head2 add_unique_constraint
+
+Declare a unique constraint on this source. Call once for each unique
+constraint.
+
+  # For e.g. UNIQUE (column1, column2)
+  __PACKAGE__->add_unique_constraint(constraint_name => [ qw/column1 column2/ ]);
+
+=cut
+
+sub add_unique_constraint {
+  my ($self, $name, $cols) = @_;
+
+  for (@$cols) {
+    $self->throw("No such column $_ on table ".$self->name)
+      unless $self->has_column($_);
+  }
+
+  my %unique_constraints = $self->unique_constraints;
+  $unique_constraints{$name} = $cols;
+  $self->_unique_constraints(\%unique_constraints);
+}
+
+=head2 unique_constraints
+
+Read-only accessor which returns the list of unique constraints on this source.
+
+=cut
+
+sub unique_constraints {
+  return %{shift->_unique_constraints||{}};
+}
+
 =head2 from
 
 Returns an expression of the source to be supplied to storage to specify
@@ -224,7 +276,7 @@ created, which calls C<create_related> for the relationship.
 
 sub add_relationship {
   my ($self, $rel, $f_source_name, $cond, $attrs) = @_;
-  die "Can't create relationship without join condition" unless $cond;
+  croak "Can't create relationship without join condition" unless $cond;
   $attrs ||= {};
 
   my %rels = %{ $self->_relationships };
@@ -257,7 +309,7 @@ sub add_relationship {
   if ($@) { # If the resolve failed, back out and re-throw the error
     delete $rels{$rel}; # 
     $self->_relationships(\%rels);
-    die "Error creating relationship $rel: $@";
+    croak "Error creating relationship $rel: $@";
   }
   1;
 }
@@ -309,10 +361,10 @@ sub resolve_join {
                  $self->related_source($_)->resolve_join($join->{$_}, $_) }
            keys %$join;
   } elsif (ref $join) {
-    die("No idea how to resolve join reftype ".ref $join);
+    croak ("No idea how to resolve join reftype ".ref $join);
   } else {
     my $rel_info = $self->relationship_info($join);
-    die("No such relationship ${join}") unless $rel_info;
+    croak("No such relationship ${join}") unless $rel_info;
     my $type = $rel_info->{attrs}{join_type} || '';
     return [ { $join => $self->related_source($join)->from,
                -join_type => $type },
@@ -335,8 +387,8 @@ sub resolve_condition {
     my %ret;
     while (my ($k, $v) = each %{$cond}) {
       # XXX should probably check these are valid columns
-      $k =~ s/^foreign\.// || die "Invalid rel cond key ${k}";
-      $v =~ s/^self\.// || die "Invalid rel cond val ${v}";
+      $k =~ s/^foreign\.// || croak "Invalid rel cond key ${k}";
+      $v =~ s/^self\.// || croak "Invalid rel cond val ${v}";
       if (ref $for) { # Object
         #warn "$self $k $for $v";
         $ret{$k} = $for->get_column($v);
