@@ -1,6 +1,8 @@
 package DBIx::Class::UUIDColumns;
 use base qw/DBIx::Class/;
 
+use Carp qw/croak/;
+
 use Data::UUID;
 
 __PACKAGE__->mk_classdata( 'uuid_auto_columns' => [] );
@@ -32,18 +34,18 @@ Note that the component needs to be loaded before Core.
 sub uuid_columns {
     my $self = shift;
     for (@_) {
-	die "column $_ doesn't exist" unless $self->has_column($_);
+	croak "column $_ doesn't exist" unless $self->has_column($_);
     }
     $self->uuid_auto_columns(\@_);
 }
 
 sub insert {
-    my ($self) = @_;
+    my $self = shift;
     for my $column (@{$self->uuid_auto_columns}) {
 	$self->store_column( $column, $self->get_uuid )
 	    unless defined $self->get_column( $column );
     }
-    $self->next::method;
+    $self->next::method(@_);
 }
 
 sub get_uuid {
